dscript.commands
================

dscript.commands.predict
------------------------

See `Prediction <../usage.html#prediction>`_ for full usage details.

.. automodule:: dscript.commands.predict
   :members:
   :undoc-members:
   :show-inheritance:

dscript.commands.embed
----------------------

See `Embedding <../usage.html#embedding>`_ for full usage details.

.. automodule:: dscript.commands.embed
   :members:
   :undoc-members:
   :show-inheritance:

dscript.commands.train
----------------------

See `Training <../usage.html#training>`_ for full usage details.

.. automodule:: dscript.commands.train
   :members:
   :undoc-members:
   :show-inheritance:

dscript.commands.evaluate
-------------------------

See `Evaluation <../usage.html#evaluation>`_ for full usage details.

.. automodule:: dscript.commands.evaluate
   :members:
   :undoc-members:
   :show-inheritance:
